==> sherpa_client-0.12.1.tar.gz: sherpa_client-0.12.1/sherpa_client/api/gazetteers/get_gazetteers.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.gazetteer import Gazetteer
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    client: Client,
    tags: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/projects/{projectName}/gazetteers".format(client.base_url, projectName=project_name)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["tags"] = tags

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["Gazetteer"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_gazetteer_array_item_data in _response_200:
            componentsschemas_gazetteer_array_item = Gazetteer.from_dict(componentsschemas_gazetteer_array_item_data)

            response_200.append(componentsschemas_gazetteer_array_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[List["Gazetteer"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Client,
    tags: Union[Unset, None, str] = UNSET,
) -> Response[List["Gazetteer"]]:
    """List gazetteers

    Args:
        project_name (str):
        tags (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['Gazetteer']]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        tags=tags,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Client,
    tags: Union[Unset, None, str] = UNSET,
) -> Optional[List["Gazetteer"]]:
    """List gazetteers

    Args:
        project_name (str):
        tags (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['Gazetteer']]
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
        tags=tags,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Client,
    tags: Union[Unset, None, str] = UNSET,
) -> Response[List["Gazetteer"]]:
    """List gazetteers

    Args:
        project_name (str):
        tags (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['Gazetteer']]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        tags=tags,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Client,
    tags: Union[Unset, None, str] = UNSET,
) -> Optional[List["Gazetteer"]]:
    """List gazetteers

    Args:
        project_name (str):
        tags (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['Gazetteer']]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
            tags=tags,
        )
    ).parsed

==> sherpa_client-1.0.3.tar.gz: sherpa_client-1.0.3/sherpa_client/api/gazetteers/get_gazetteers.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.gazetteer import Gazetteer
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    tags: Union[Unset, str] = UNSET,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    params["tags"] = tags

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/projects/{project_name}/gazetteers".format(
            project_name=project_name,
        ),
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[list["Gazetteer"]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_gazetteer_array_item_data in _response_200:
            componentsschemas_gazetteer_array_item = Gazetteer.from_dict(
                componentsschemas_gazetteer_array_item_data
            )

            response_200.append(componentsschemas_gazetteer_array_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[list["Gazetteer"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    tags: Union[Unset, str] = UNSET,
) -> Response[list["Gazetteer"]]:
    """List gazetteers

    Args:
        project_name (str):
        tags (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['Gazetteer']]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        tags=tags,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    tags: Union[Unset, str] = UNSET,
) -> Optional[list["Gazetteer"]]:
    """List gazetteers

    Args:
        project_name (str):
        tags (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['Gazetteer']
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
        tags=tags,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    tags: Union[Unset, str] = UNSET,
) -> Response[list["Gazetteer"]]:
    """List gazetteers

    Args:
        project_name (str):
        tags (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['Gazetteer']]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        tags=tags,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    tags: Union[Unset, str] = UNSET,
) -> Optional[list["Gazetteer"]]:
    """List gazetteers

    Args:
        project_name (str):
        tags (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['Gazetteer']
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
            tags=tags,
        )
    ).parsed
